USE [Office]
DECLARE @Updated tinyint = 0
IF EXISTS (SELECT 1 FROM DatabaseVersion WHERE Version = '71' AND SubVersion = '1')
BEGIN
	IF NOT EXISTS (SELECT 1 FROM sys.indexes WHERE name = 'idxAttendingOffice' AND object_id = OBJECT_ID('[dbo].[ProvidersAttending]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxAttendingOffice] ON [dbo].[ProvidersAttending]
		(
			[OfficeID] ASC
		)
		INCLUDE([LastName],[FirstName],[SpecialtyID],[ExamTypeID],[FeeScheduleID],[PayorID],[Notes],[PhysicianAssistant],[Archive],[ReauditDate],[Revision],[RevisionDate])
	END
	IF NOT EXISTS (SELECT 1 FROM sys.indexes WHERE name = 'idxPatientOffice' AND object_id = OBJECT_ID('[dbo].[Patients]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxPatientOffice] ON [dbo].[Patients]
		(
			[OfficeID] ASC
		)
		INCLUDE([PatientID],[LastName],[FirstName],[DOB],[Gender],[Revision],[RevisionDate])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxFinalReaudit' AND object_id = OBJECT_ID('[dbo].[VisitFinal]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxFinalReaudit] ON [dbo].[VisitFinal]
		(
			[VisitID] ASC
		)
		INCLUDE([ProviderCode],[UserCode],[Variance],[ProcedureTotal],[ProcedureAccurate],[DiagnosisTotal],[DiagnosisAccurate])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxProcedureCover' AND object_id = OBJECT_ID('[dbo].[VisitProcedures]'))
	BEGIN
		CREATE UNIQUE NONCLUSTERED INDEX [idxProcedureCover] ON [dbo].[VisitProcedures]
		(
			[VisitID] ASC,
			[Ordinal] ASC,
			[Provider] ASC
		)
		INCLUDE([Code],[Description],[modifier],[fee],[RVU])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxMasterFilter' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxMasterFilter] ON [dbo].[VisitMaster]
		(
			[OfficeID] ASC,
			[Deleted] ASC,
			[Archive] ASC
		)
		INCLUDE([VisitID],[ChildVisitID],[PatientID],[VisitDate],[AuditDate],[Status],[AttendingProviderID],[RequestingProviderID],[UserID],[PayorID],[ServiceTypeID],[SubServiceTypeID],[Notes],[MetConsultRequirements],[MetIncidentToRequirements],[ResidentID],[TeachingCode],[RVUFacility],[EditedVisitID],[FeeConversionFactor],[AuditedDocumentID],[Revision],[RevisionDate],[VisitSecondaryID])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxVisitState' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxVisitState] ON [dbo].[VisitMaster]
		(
			[Deleted] ASC,
			[Archive] ASC
		)
		INCLUDE([OfficeID])
	END
	
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxDiagnosisCover' AND object_id = OBJECT_ID('[dbo].[VisitDiagnosis]'))
	BEGIN
		CREATE UNIQUE NONCLUSTERED INDEX [idxDiagnosisCover] ON [dbo].[VisitDiagnosis]
		(
			[VisitID] ASC,
			[Ordinal] ASC,
			[Provider] ASC,
			[DiagnosisOrdinal] ASC
		)
		INCLUDE([ProcedureCode],[DiagnosisCode],[DiagnosisDescription],[Version])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxHistoryCover' AND object_id = OBJECT_ID('[dbo].[VisitHistory]'))
	BEGIN
		CREATE UNIQUE NONCLUSTERED INDEX [idxHistoryCover] ON [dbo].[VisitHistory]
		(
			[HistoryItemID] ASC,
			[VisitID] ASC
		)
		INCLUDE ([historyElementValue])
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxTime_Type' AND object_id = OBJECT_ID('[dbo].[AuditTrail]'))
	BEGIN
		CREATE NONCLUSTERED INDEX [idxTime_Type] ON [dbo].[AuditTrail]
		(
			[timestamp] ASC,
			[AreaID] ASC,
			[ActionID] ASC
		)
		INCLUDE([LogMasterID])
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxVisitID' AND object_id = OBJECT_ID('[dbo].[VisitDiagnosis]'))
	BEGIN
		DROP INDEX [idxVisitID] ON [dbo].[VisitDiagnosis]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxVisitID' AND object_id = OBJECT_ID('[dbo].[VisitProcedures]'))
	BEGIN
		DROP INDEX [idxVisitID] ON [dbo].[VisitProcedures]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxAPOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxAPOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxArchive' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxArchive] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxDeleted' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxDeleted] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxPatientOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxPatientOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxPayorOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxPayorOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxResidentOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxResidentOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxRPOfficeID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxRPOfficeID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxUserID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxUserID] ON [dbo].[VisitMaster]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxAction' AND object_id = OBJECT_ID('[dbo].[AuditTrail]'))
	BEGIN
		DROP INDEX [idxAction] ON [dbo].[AuditTrail]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxArea' AND object_id = OBJECT_ID('[dbo].[AuditTrail]'))
	BEGIN
		DROP INDEX [idxArea] ON [dbo].[AuditTrail]
	END
	IF EXISTS (SELECT 1 from sys.indexes where name = 'idxChildVisitID' AND object_id = OBJECT_ID('[dbo].[VisitMaster]'))
	BEGIN
		DROP INDEX [idxChildVisitID] ON [dbo].[VisitMaster];
	END 
	CREATE NONCLUSTERED INDEX [idxChildVisitID] ON [dbo].[VisitMaster]
	(
		[ChildVisitID] ASC,
		[OfficeID] ASC
	)
	INCLUDE([VisitID])
	UPDATE DatabaseVersion SET Version='71', SubVersion='2';
	set @Updated = 1
	Print('Database Updated to 71.2')
END
IF EXISTS (SELECT 1 FROM DatabaseVersion WHERE Version = '71' AND SubVersion = '2')
BEGIN
	IF NOT EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'VisitFinal' and COLUMN_NAME = 'MultipleHPI')
	BEGIN
		ALTER TABLE VisitFinal ADD MultipleHPI bit NOT NULL DEFAULT 1;
	END
	IF NOT EXISTS (SELECT 1 from sys.indexes where name = 'idxFinalCover' AND object_id = OBJECT_ID('[dbo].[VisitFinal]'))
	BEGIN
		CREATE UNIQUE NONCLUSTERED INDEX [idxFinalCover] ON [dbo].[VisitFinal]
		(
			[VisitID] ASC
		)
		INCLUDE([FaceToFaceTime],[CounselingTime],[ProviderCode],[ProviderModifiers],[UserCode],[UserModifiers],[FeeScheduleID],[Variance],[HistoryLevel],[ExamTypeID],[ExamLevel],[DecisionTypeID],[DecisionLevel],[DC],[PsychTime],[ProlongedTime],[isNeonatalTransport],[isHypothermic],[DaysHypothermic],[Area],[ProviderEMFee],[ReviewerEMFee],[ProviderOtherFee],[ReviewerOtherFee],[ProviderEMRVU],[ReviewerEMRVU],[ProviderOtherRVU],[ReviewerOtherRVU],[ProcedureTotal],[ProcedureAccurate],[DiagnosisTotal],[DiagnosisAccurate],[TimeBased],[HistoryTypeID],[MDMRequired],[PreferTime])
	END
	EXEC ('ALTER PROCEDURE [dbo].[SendVisits] --Sends to one office
	                                           @sourceVisits nvarchar(max),  --this contains CSV with visitIDs being sent
	                                           @receivingOfficeID varchar(50),
	                                           @oldToNewParam VisitSendUpdates READONLY,--Table value parameter. Columns are sourceVisitID, oldItemOfficeID, targetOfficeID, newPatientID, newProviderID, newRequesterID, newPayorID, newResidentID, newDocumentID, newFeeScheduleID, newRisk.
	                                           @oldToNewNoteMacros NoteMacroChanges READONLY--Table value parameter. Columns are sourceVisitID, sourceNoteMacroID, targetNoteMacroID
	                                       AS
	                                       SET NOCOUNT OFF;
	                                      
	                                       BEGIN TRANSACTION VisitSend;
	                                      
	                                       SELECT * INTO #oldToNew FROM (SELECT * FROM @oldToNewParam) AS oldToNew --Throw the table parameter into a temp table.
	                                       SELECT * INTO #oldToNewNoteMacros FROM (SELECT * FROM @oldToNewNoteMacros) AS VNMChanges --Throw the table parameter into a temp table.
	                                      
	                                       CREATE TABLE #VisitIDs
	                                       (
	                                        sourceVisitID varchar(50),
	                                        targetVisitID varchar(50)
	                                       )
	                                       INSERT INTO #VisitIDs --Fill the table with source - target visit IDs. Create a new GUID for each sent visit
	                                       SELECT Split.Item as sourceVisitID, LOWER(REPLACE(NEWID(), ''-'', '''')) as targetVisitID
	                                       FROM SplitStrings_CTE(@sourceVisits,'','') as Split
	                                       --Insert new rows based on existing visits, replacing some IDs. The underlying items should have already been copied by Intelicode
	                                       INSERT INTO VisitMaster
	                                           SELECT targetVisitID AS VisitID
		                                           ,@receivingOfficeID AS OfficeID
		                                           ,CASE WHEN oldToNew.newPatientID is not null THEN oldToNew.newPatientID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.PatientID END AS PatientID 
		                                           ,vmSource.VisitDate
		                                           ,vmSource.AuditDate
		                                           ,vmSource.Status
		                                           ,CASE WHEN oldToNew.newProviderID is not null THEN oldToNew.newProviderID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.AttendingProviderID END AS AttendingProviderID
		                                           ,CASE WHEN oldToNew.newRequesterID is not null THEN oldToNew.newRequesterID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.RequestingProviderID END AS RequestingProviderID
		                                           ,vmSource.UserID
		                                           ,CASE WHEN oldToNew.newPayorID is not null THEN oldToNew.newPayorID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.PayorID END AS PayorID
		                                           ,vmSource.ServiceTypeID
		                                           ,vmSource.SubServiceTypeID
		                                           ,vmSource.Notes
		                                           ,vmSource.Archive
		                                           ,vmSource.Deleted
		                                           ,CASE WHEN vmSource.ChildVisitID is not null THEN (SELECT targetVisitID FROM #VisitIDs WHERE sourceVisitID = vmSource.ChildVisitID COLLATE SQL_Latin1_General_CP1_CS_AS) COLLATE SQL_Latin1_General_CP1_CS_AS ELSE NULL END AS ChildVisitID
		                                           ,vmSource.MetConsultRequirements
		                                           ,vmSource.MetIncidentToRequirements
		                                           ,CASE WHEN oldToNew.newResidentID is not null THEN oldToNew.newResidentID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.ResidentID END AS ResidentID
		                                           ,vmSource.TeachingCode
		                                           ,vmSource.RVUFacility
		                                           ,vmSource.EditedVisitID
		                                           ,vmSource.FeeConversionFactor
		                                           ,CASE WHEN oldToNew.newDocumentID is not null THEN oldToNew.newDocumentID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE vmSource.AuditedDocumentID END AS AuditedDocumentID
		                                           ,1 as Revision
		                                           ,GETUTCDATE() as RevisionDate
	                                           FROM VisitMaster vmSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = vmSource.VisitID
	                                           LEFT JOIN #oldToNew AS oldToNew
	                                           ON oldToNew.oldItemOfficeID = vmSource.OfficeID COLLATE SQL_Latin1_General_CP1_CS_AS
	                                           AND oldToNew.sourceVisitID = vmSource.VisitID COLLATE SQL_Latin1_General_CP1_CS_AS
	                                           WHERE vmSource.OfficeID <> @receivingOfficeID COLLATE SQL_Latin1_General_CP1_CS_AS;
	                                      
	                                       INSERT INTO VisitFinal
	                                           SELECT targetVisitID AS VisitID
	                                                  ,vfSource.FaceToFaceTime
	                                                  ,vfSource.CounselingTime
	                                                  ,vfSource.ProviderCode
	                                                  ,vfSource.ProviderModifiers
		                                              ,vfSource.UserCode
	                                                  ,vfSource.UserModifiers
	                                                  ,CASE WHEN oldToNew.newFeeScheduleID is not null THEN oldToNew.newFeeScheduleID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE NULL END AS FeeScheduleID --Don''t send the fee schedule ID, that''s office-specific
	                                                  ,vfSource.Variance
	                                                  ,vfSource.HistoryLevel
	                                                  ,vfSource.ExamTypeID
	                                                  ,vfSource.ExamLevel
	                                                  ,vfSource.DecisionTypeID
	                                                  ,vfSource.DecisionLevel
	                                                  ,vfSource.DC
	                                                  ,vfSource.PsychTime
	                                                  ,vfSource.ProlongedTime
	                                                  ,vfSource.isNeonatalTransport
	                                                  ,vfSource.isHypothermic
	                                                  ,vfSource.DaysHypothermic
	                                                  ,vfSource.Area
	                                                  ,vfSource.ProviderEMFee
	                                                  ,vfSource.ReviewerEMFee
	                                                  ,vfSource.ProviderOtherFee
	                                                  ,vfSource.ReviewerOtherFee
	                                                  ,vfSource.ProviderEMRVU
	                                                  ,vfSource.ReviewerEMRVU
	                                                  ,vfSource.ProviderOtherRVU
	                                                  ,vfSource.ReviewerOtherRVU
	                                                  ,vfSource.ProcedureTotal
	                                                  ,vfSource.ProcedureAccurate
	                                                  ,vfSource.DiagnosisTotal
	                                                  ,vfSource.DiagnosisAccurate
	                                                  ,vfSource.TimeBased
			                                          ,vfSource.HistoryTypeID
			                                          ,vfSource.MDMRequired
													  ,vfSource.PreferTime
                                                      ,vfSource.MultipleHPI
	                                           FROM VisitFinal AS vfSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = vfSource.VisitID
	                                           LEFT JOIN #oldToNew AS oldToNew
	                                           ON oldToNew.sourceVisitID = vfSource.VisitID COLLATE SQL_Latin1_General_CP1_CS_AS;
	                                      
	                                       INSERT INTO VisitCMSDecision
	                                           SELECT targetVisitID AS VisitID
	                                                 ,cmsSource.NumberOfDiagnosis
	                                                 ,cmsSource.EstablishedImproved
	                                                 ,cmsSource.EstablishedFailing
	                                                 ,cmsSource.NewNoAdditionalWork
	                                                 ,cmsSource.NewAdditionalWork
	                                                 ,cmsSource.ReviewLabTests
	                                                 ,cmsSource.ReviewRadiology
	                                                 ,cmsSource.ReviewMedicine
	                                                 ,cmsSource.DiscussTests
	                                                 ,cmsSource.IndependentReview
	                                                 ,cmsSource.DiscussOldRecords
	                                                 ,cmsSource.ReviewOldRecords
	                                                 ,CASE WHEN oldToNew.newRisk is not null THEN oldToNew.newRisk ELSE cmsSource.Risk END AS Risk 
	                                           FROM VisitCMSDecision AS cmsSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = cmsSource.VisitID
	                                           LEFT JOIN #oldToNew as oldToNew
	                                           ON oldToNew.sourceVisitID = cmsSource.VisitID COLLATE SQL_Latin1_General_CP1_CS_AS;
	                                      
	                                       INSERT INTO VisitTrailBlazerDecision
	                                           SELECT targetVisitID AS VisitID
	                                                 ,vtbDecisionSource.ProblemsEvident
	                                                 ,vtbDecisionSource.OpenProcedure
	                                                 ,vtbDecisionSource.PhysicalTherapy
	                                                 ,vtbDecisionSource.ClosedTreatment
	                                                 ,vtbDecisionSource.IVFluids
	                                                 ,vtbDecisionSource.ComplexInsulin
	                                                 ,vtbDecisionSource.ConservativeMeasures
	                                                 ,vtbDecisionSource.RadiationTherapy
	                                                 ,vtbDecisionSource.JointInjection
	                                                 ,vtbDecisionSource.PatientEducation
	                                                 ,vtbDecisionSource.AdmitHospital
	                                                 ,vtbDecisionSource.DiscussCaseManagement_Options
	                                                 ,vtbDecisionSource.Other
	                                                 ,vtbDecisionSource.LabProcedures
	                                                 ,vtbDecisionSource.RadiologyProcedures
	                                                 ,vtbDecisionSource.MedicalProcedures
	                                                 ,vtbDecisionSource.IndependentVisualizations
	                                                 ,vtbDecisionSource.DiscussTestResults
	                                                 ,vtbDecisionSource.DiscussCaseDataReviewed
	                                                 ,vtbDecisionSource.PhysiologicMonitoring
	                                                 ,vtbDecisionSource.OrderNoSummary
	                                                 ,vtbDecisionSource.OrderSummary
	                                                 ,vtbDecisionSource.DecisionProblems
	                                                 ,CASE WHEN oldToNew.newRisk is not null THEN oldToNew.newRisk ELSE vtbDecisionSource.DecisionRisk END AS DecisionRisk
	                                           FROM VisitTrailblazerDecision AS vtbDecisionSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = vtbDecisionSource.VisitID
	                                           LEFT JOIN #oldToNew as oldToNew
	                                           ON oldToNew.sourceVisitID = vtbDecisionSource.VisitID COLLATE SQL_Latin1_General_CP1_CS_AS;
	                                      
	                                       INSERT INTO VisitNoteMacros 
	                                           SELECT targetVisitID AS VisitID
	                                             ,NMChange.targetNoteMacroID COLLATE SQL_Latin1_General_CP1_CS_AS AS NoteMacroID 
	                                             --,CASE WHEN NMChange.targetNoteMacroID is not null THEN NMChange.targetNoteMacroID COLLATE SQL_Latin1_General_CP1_CS_AS ELSE nmSource.NoteMacroID END AS NoteMacroID
	                                           FROM VisitNoteMacros AS nmSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = nmSource.VisitID
	                                           INNER JOIN #oldToNewNoteMacros AS NMChange
	                                           ON NMChange.sourceVisitID = nmSource.VisitID
	                                           AND NMChange.sourceNoteMacroID = nmSource.NoteMacroID
	                                           WHERE NMChange.targetNoteMacroID is not null --Shouldn''t ever be null, but if it is, don''t insert
	                                      
	                                       INSERT INTO VisitProcedures
	                                           SELECT targetVisitID AS VisitID
	                                                 ,procSource.Provider
	                                                 ,procSource.Ordinal
	                                                 ,procSource.Code
	                                                 ,procSource.Description
	                                                 ,procSource.modifier
	                                                 ,procSource.fee
	                                                 ,procSource.RVU
	                                           FROM VisitProcedures AS procSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = procSource.VisitID;
	                                      
	                                       INSERT INTO VisitDiagnosis
	                                           SELECT targetVisitID AS VisitID
	                                                 ,diagSource.Provider
	                                                 ,diagSource.Ordinal
	                                                 ,diagSource.ProcedureCode
	                                                 ,diagSource.DiagnosisCode
	                                                 ,diagSource.DiagnosisDescription
	                                                 ,diagSource.Version
	                                                 ,diagSource.DiagnosisOrdinal
	                                           FROM VisitDiagnosis AS diagSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = diagSource.VisitID;
	                                      
	                                       INSERT INTO VisitConsult
	                                           SELECT targetVisitID AS VisitID
	                                             ,consultSource.QuestionNumber
	                                             ,consultSource.[Continue]
	                                           FROM VisitConsult AS consultSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = consultSource.VisitID;
	                                      
	                                       INSERT INTO VisitExamElements
	                                           SELECT targetVisitID AS VisitID
	                                                 ,examSource.ExamTypeID
	                                                 ,examSource.ExamElementID
	                                           FROM VisitExamElements AS examSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = examSource.VisitID;
	                                      
	                                       INSERT INTO VisitHistory
	                                           SELECT targetVisitID AS VisitID
	                                                 ,historySource.HistoryItemID
	                                                 ,historySource.historyElementValue
	                                           FROM VisitHistory AS historySource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = historySource.VisitID;
	                                      
	                                       INSERT INTO VisitHistoryLevels
	                                           SELECT targetVisitID AS VisitID
	                                                 ,historySource.HPILevel
	                                                 ,historySource.ROSLevel
	                                                 ,historySource.PFSHLevel
	                                           FROM VisitHistoryLevels AS historySource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = historySource.VisitID;
	                                      
	                                       INSERT INTO VisitHistoryUnobtainable
	                                           SELECT targetVisitID AS VisitID
	                                             ,historySource.HistoryUnobtainableLevel
	                                             ,historySource.HistoryUnobtainableReason
	                                           FROM VisitHistoryUnobtainable AS historySource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = historySource.VisitID;
	                                      
	                                       INSERT INTO VisitIncidentTo
	                                           SELECT targetVisitID AS VisitID
	                                             ,incidentToSource.QuestionNumber
	                                             ,incidentToSource.[Continue]
	                                           FROM VisitIncidentTo AS incidentToSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = incidentToSource.VisitID;
	                                      
	                                       INSERT INTO VisitMedicalNecessity 
	                                           SELECT targetVisitID AS VisitID
	                                             ,vmnSource.QuestionNumber
	                                             ,vmnSource.Selection
	                                           FROM VisitMedicalNecessity AS vmnSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = vmnSource.VisitID;
	                                      
	                                       INSERT INTO VisitOtherQuestions
	                                           SELECT targetVisitID AS VisitID 
	                                             ,questionSource.QuestionTypeID
	                                             ,questionSource.QuestionNumber
	                                             ,questionSource.[Continue]
	                                           FROM VisitOtherQuestions AS questionSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = questionSource.VisitID;
	                                      
	                                       INSERT INTO VisitPreventiveSplitVisit
	                                           SELECT targetVisitID AS VisitID
	                                             ,splitSource.QuestionNumber
	                                             ,splitSource.[Continue]
	                                           FROM VisitPreventiveSplitVisit AS splitSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = splitSource.VisitID;
	                                      
	                                       INSERT INTO VisitTeachingPhysician
	                                           SELECT targetVisitID AS VisitID
	                                             ,tpSource.QuestionNumber
	                                             ,tpSource.[Continue]
	                                           FROM VisitTeachingPhysician AS tpSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = tpSource.VisitID;
	                                      
	                                       INSERT INTO VisitWelcomeToMedicare
	                                           SELECT targetVisitID AS VisitID
	                                             ,wtmSource.QuestionNumber
	                                             ,wtmSource.[Continue]
	                                           FROM VisitWelcomeToMedicare AS wtmSource
	                                           INNER JOIN #VisitIDs AS visitIDs
	                                           ON VisitIDs.sourceVisitID = wtmSource.VisitID;
	                                      
	                                       COMMIT TRANSACTION VisitSend;
	                                      
	                                       --Return the new IDs and the source visit ID
	                                       SELECT #VisitIDs.sourceVisitID AS SourceVisitID
	                                               , VisitMaster.VisitID AS TargetVisitID
	                                               , VisitMaster.VisitSecondaryID AS TargetSecondaryID
	                                       FROM VisitMaster
	                                       INNER JOIN #VisitIDs
	                                       ON #VisitIDs.targetVisitID = VisitMaster.VisitID')
	EXEC ('ALTER TRIGGER [dbo].[tr_VisitFinalInsert] ON [dbo].[VisitFinal]
                                        INSTEAD OF INSERT
                                        AS
                                        BEGIN
                                            SELECT * INTO #tmp from inserted
                                            UPDATE #tmp
                                            SET FeeScheduleID =
    	                                        CASE WHEN FeeScheduleID is not null THEN --if provider ID not null, check if it still exists
    		                                        CASE WHEN FeeScheduleID not in (SELECT FeeScheduleID FROM FeeSchedules) THEN --Office ID may be important, but Final doesn''t have it to compare and FSID is a GUID anyway
    			                                        NULL
    		                                        ELSE
    			                                        FeeScheduleID
    		                                        END
    	                                        ELSE
    		                                        NULL
    	                                        END
                                            INSERT INTO VisitFinal (VisitID, FaceToFaceTime, CounselingTime, ProviderCode, ProviderModifiers, UserCode, UserModifiers, 
	                                        FeeScheduleID, Variance, HistoryTypeID, HistoryLevel, ExamTypeID, ExamLevel, DecisionTypeID, DecisionLevel, DC, PsychTime, ProlongedTime, 
	                                        isNeonatalTransport, isHypothermic, DaysHypothermic, Area, ProviderEMFee, ReviewerEMFee, ProviderOtherFee, ReviewerOtherFee,
	                                        ProviderEMRVU, ReviewerEMRVU, ProviderOtherRVU, ReviewerOtherRVU, ProcedureTotal, ProcedureAccurate, DiagnosisTotal, 
	                                        DiagnosisAccurate, TimeBased, MDMRequired, PreferTime, MultipleHPI)
	                                        SELECT VisitID, FaceToFaceTime, CounselingTime, ProviderCode, ProviderModifiers, UserCode, UserModifiers, 
	                                        FeeScheduleID, Variance, HistoryTypeID, HistoryLevel, ExamTypeID, ExamLevel, DecisionTypeID, DecisionLevel, DC, PsychTime, ProlongedTime, 
	                                        isNeonatalTransport, isHypothermic, DaysHypothermic, Area, ProviderEMFee, ReviewerEMFee, ProviderOtherFee, ReviewerOtherFee,
	                                        ProviderEMRVU, ReviewerEMRVU, ProviderOtherRVU, ReviewerOtherRVU, ProcedureTotal, ProcedureAccurate, DiagnosisTotal, 
	                                        DiagnosisAccurate, TimeBased, MDMRequired, PreferTime, MultipleHPI
	                                        FROM #tmp
                                            DROP TABLE #tmp
                                        END')

	EXEC ('ALTER VIEW [dbo].[v_VisitSummaries] AS
	                                --XML Sections must do COALESCE on nullable fields for an element tag to be returned
	                                SELECT vm.PatientID as ''Pat. ID'',
	                                CASE WHEN (p.LastName is null or p.LastName = '''') and (p.FirstName is null or p.FirstName = '''') THEN ''''
	                                WHEN (p.LastName is null or p.LastName = '''') THEN p.FirstName
	                                WHEN (p.FirstName is null or p.FirstName = '''') THEN p.LastName
	                                ELSE p.LastName + '', '' + p.FirstName END as Patient,
	                                vm.UserID as ReviewerID,
	                                CASE WHEN (u.LastName is null or u.LastName = '''') and (u.FirstName is null or u.FirstName = '''') THEN ''''
	                                WHEN (u.LastName is null or u.LastName = '''') THEN u.FirstName --breaking this out is faster than nested case statements
	                                WHEN (u.FirstName is null or u.FirstName = '''') THEN u.LastName
	                                ELSE u.LastName + '', '' + u.FirstName END as Reviewer,
	                                COALESCE(vm.VisitDate, 01/01/0001) as ''Visit Dt.'', COALESCE(vm.AuditDate, 01/01/0001) as ''Audit Dt.'',
	                                pa.ProviderID as ''ProviderID'',
	                                CASE WHEN (pa.LastName is null or pa.LastName = '''') and (pa.FirstName is null or pa.FirstName = '''') THEN ''''
	                                WHEN (pa.LastName is null or pa.LastName = '''') THEN pa.FirstName
	                                WHEN (pa.FirstName is null or pa.FirstName = '''') THEN pa.LastName
	                                 ELSE pa.LastName + '', '' + pa.FirstName END as Provider,
	                                COALESCE(vm.ServiceTypeID, -1) as ''ServicetypeID'',
	                                -1 as ''SubserviceTypeID'',
	                                vf.ProviderCode as ''Provider Code'',
	                                vf.ProviderModifiers,
	                                vf.UserModifiers,
	                                CASE WHEN vf.Variance is null OR vf.Variance = '''' THEN
	                                    CASE WHEN vf.ProviderCode = vf.UserCode THEN
	                                        ''0''
	                                    ELSE ''WC''
	                                    END
	                                ELSE vf.Variance
	                                END as ''Var'',
	                                vf.UserCode as ''Reviewer Code'',
	                                CASE WHEN vf.DC = 1 THEN ''-DC'' ELSE '''' END as ''DC'',
	                                CASE WHEN vm.MetIncidentToRequirements is null THEN
	                                    ''''
	                                WHEN vm.MetIncidentToRequirements = 1 THEN
	                                    ''True''
	                                ELSE
	                                    ''False''
	                                END as ''IT'',
	                                CASE WHEN vm.MetConsultRequirements is null THEN
	                                    ''''
	                                WHEN vm.MetConsultRequirements = 1 THEN
	                                    ''True''
	                                ELSE
	                                    ''False''
	                                END as ''MetConsultRequirements'',
	                                --Diff calculated in Intelicode- (ProviderFee-ReviewerFee) - based on preference value useOtherServices in Fees and RVUs
	                                r.ResidentID,
	                                CASE WHEN (r.LastName is null or r.LastName = '''') and (r.FirstName is null or r.FirstName = '''') THEN ''''
	                                WHEN (r.LastName is null or r.LastName = '''') THEN r.FirstName
	                                WHEN (r.FirstName is null or r.FirstName = '''') THEN r.LastName
	                                ELSE r.LastName + '', '' + r.FirstName END as Resident,
	                                s.SpecialtyID,
	                                s.Specialty as Specialty,
	                                CASE WHEN vm.RVUFacility is null THEN o.RVUFacility ELSE vm.RVUFacility END as ''RVUFacility'',
	                                vm.TeachingCode as TP,
	                                COALESCE(vf.ProviderEMRVU, 0.0) as ''ProviderEMRVU'', --used to get ProviderRVU in Intelicode
	                                COALESCE(vf.ProviderOtherRVU, 0.0) as ''ProviderOtherRVU'', --used to get ProviderRVU in Intelicode
	                                COALESCE(vf.ReviewerEMRVU, 0.0) as ''ReviewerEMRVU'', --used to get User RVU in Intelicode
	                                COALESCE(vf.ReviewerOtherRVU, 0.0) as ''ReviewerOtherRVU'', --used to get User RVU in Intelicode
	                                COALESCE(vf.ProviderEMFee, 0.0) as ProviderEMFee, --Provider Fee
	                                COALESCE(vf.ProviderOtherFee, 0.0) as ProviderOtherFee,
	                                COALESCE(vf.ReviewerEMFee, 0.0) as ReviewerEMFee, --User Fee
	                                COALESCE(vf.ReviewerOtherFee, 0.0) as ReviewerOtherFee,
	                                vm.RequestingProviderID,
	                                CASE WHEN (pr.LastName is null or pr.LastName = '''') and (pr.FirstName is null or pr.FirstName = '''') THEN ''''
	                                WHEN (pr.LastName is null or pr.LastName = '''') THEN pr.FirstName
	                                WHEN (pr.FirstName is null or pr.FirstName = '''') THEN pr.LastName
	                                ELSE pr.LastName + '', '' + pr.FirstName END as Requester,
	                                COALESCE(vf.ExamTypeID, -1) as ''Exam Type Id'', COALESCE(vf.ExamLevel, -1) as ''ExamLevel'',
	                                COALESCE(vf.DecisionTypeID, -1) as ''DecisionTypeID'', COALESCE(vf.DecisionLevel, -1) as ''DecisionLevel'',
	                                vf.HistoryTypeID,
	                                vf.HistoryLevel,
	                                COALESCE(vf.DiagnosisAccurate, 0) as ''DiagnosisAccurate'', p.DOB as ''dateOfBirth'', p.Gender, COALESCE(vf.DiagnosisTotal, 0) as ''DiagnosisTotal'', COALESCE(vf.ProcedureAccurate, 0) as ''ProceduresAccurate'', COALESCE(vf.ProcedureTotal, 0) as ''ProceduresTotal'',
	                                vm.OfficeID, o.Name as Office, COALESCE(pay.PayorName, '''') as ''Payor'', pay.PayorID,
	                                vm.AuditedDocumentID, ad.DocumentName as AuditedDocumentName,
	                                vm.VisitSecondaryID as ''VisitID'',
	                                fs.FeeScheduleName as ''Fee Schedule'', fs.FeeScheduleID,
	                                vm.Status as ''Stat'', --formatted in Intelicode
	                                CASE WHEN vm.RevisionDate is null THEN COALESCE(vm.AuditDate, 01/01/0001) ELSE vm.RevisionDate END as ''Revision Dt.'',
	                                vm.Revision,
	                                vm.ChildVisitID as ''ChildVisitID'',
	                                parentVM.VisitID as ParentVisitID,
	                                vm.FeeConversionFactor,
	                                vf.isNeonatalTransport as ''IsTransportingNeonate'',
	                                vf.isHypothermic as ''isHypothermic'',
	                                vf.DaysHypothermic,
	                                vf.TimeBased,
	                                vf.MDMRequired,
									vf.PreferTime,
                                    vf.MultipleHPI,
	                                vf.Area,
	                                vf.PsychTime,
	                                vf.ProlongedTime as ''ProlongedFaceToFace'',
	                                vf.CounselingTime,
	                                vf.FaceToFaceTime,
	                                vf.VisitID as ''VisitMasterID'',
	                                vm.Deleted,
	                                vm.Archive,
	                                vm.Notes,
	                                COALESCE(Diagnoses.rowXML, ''<table></table>'') as ''Diagnosis'',
	                                COALESCE(ProcsAndDxs.procXML, ''<table></table>'') as ''Procedures'',
	                                COALESCE(VNoteMacros.xml, '''') as ''issuesAndRecommendations'',
	                                COALESCE(OfficePoints.rowXML, ''<table></table>'') as ''OfficePointPreferences'',
	                                vhl.HPILevel as HPILevel,
	                                vhl.ROSLevel as ROSLevel,
	                                vhl.PFSHLevel as PFSHLevel,
	                                HistoryElements.rowXML as ''HistoryElements'',
	                                CASE WHEN vhu.VisitID is null THEN 0 ELSE 1 END as ''hasHistoryUnobtainable'',
	                                vhu.HistoryUnobtainableLevel,
	                                vhu.HistoryUnobtainableReason,
	                                ExamElements.rowXML as ''ExamElements'',
	                                CMSDecisionElements.rowXML as ''CMSDecisionElements'',
	                                TrailblazerDecisionElements.rowXML as ''TrailblazerDecisionElements'',
	                                ConsultQuestions.rowXML as ''ConsultQuestions'',
	                                IncidentToQuestions.rowXML as ''IncidentToQuestions'',
	                                MedicalNecessityQuestions.rowXML as ''MedicalNecessityQuestions'',
	                                OtherQuestions.rowXML as ''OtherQuestions'',
	                                PreventiveSplitVisitQuestions.rowXML as ''PreventiveSplitVisitQuestions'',
	                                TeachingPhysicianQuestions.rowXML as ''TeachingPhysicianQuestions'',
	                                WelcomeToMedicareQuestions.rowXML as ''WelcomeToMedicareQuestions'',
	                                COALESCE(DocumentData.rowXML, ''<Document></Document>'') as ''AuditedDocument''
	                                --select *
	                                FROM VisitMaster as vm
	                                left join (SELECT VisitID, ChildVisitID FROM VisitMaster WHERE ChildVisitID is not null) as parentVM
	                                on vm.VisitID = parentVM.ChildVisitID
	                                left join VisitFinal as vf
	                                on vm.VisitID = vf.VisitID
	                                left join Offices as o
	                                on vm.OfficeID = o.OfficeID
	                                left join Patients as p
	                                on vm.PatientID = p.PatientID
	                                AND vm.OfficeID = p.OfficeID
	                                left join Users as u
	                                on vm.UserID = u.UserID
	                                left join ProvidersAttending as pa
	                                on vm.AttendingProviderID = pa.ProviderID
	                                AND vm.OfficeID = pa.OfficeID
	                                left join Specialties as s
	                                on pa.SpecialtyID = s.SpecialtyID
	                                AND pa.OfficeID = s.OfficeID
	                                left join ProvidersRequesting as pr
	                                on vm.RequestingProviderID = pr.ProviderID
	                                AND vm.OfficeID = pr.OfficeID
	                                left join Residents as r
	                                on vm.ResidentID = r.ResidentID
	                                AND vm.OfficeID = r.OfficeID
	                                left join Payors as pay
	                                on vm.PayorID = pay.PayorID
	                                AND vm.OfficeID = pay.OfficeID
	                                left join FeeSchedules as fs
	                                on vf.FeeScheduleID = fs.FeeScheduleID
	                                left join (SELECT DocumentID, DocumentName FROM Documents WHERE DocumentParentID is not null) as ad --can only be used in visit if audited document.
	                                on vm.AuditedDocumentID = ad.DocumentID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    Provider as ''Provider'',
	                                    Ordinal as ''Ordinal'',
	                                    ProcedureCode as ''ProcedureCode'',
	                                    DiagnosisCode as ''DiagnosisCode'',
	                                    DiagnosisDescription as ''DiagnosisDescription'',
	                                    [Version] as ''Version'',
	                                    DiagnosisOrdinal as ''DiagnosisOrdinal''
	                                  FROM VisitDiagnosis as b
	                                  where a.VisitID = b.VisitID
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitDiagnosis as a
	                                  GROUP BY VisitID
	                                ) as Diagnoses
	                                on vm.VisitID = Diagnoses.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    procb.VisitID as ''VisitID'',
	                                    procb.Provider as ''Provider'',
	                                    procb.Ordinal as ''Ordinal'',
	                                    procb.Code as ''Code'',
	                                    procb.[Description] as ''Description'',
	                                    procb.modifier as ''modifier'',
	                                    procb.fee as ''fee'',
	                                    procb.RVU as ''RVU'',
	                                    COALESCE(Diagnoses.rowXML, '''') as ''Diagnoses''
	                                  FROM VisitProcedures as procb
	                                  left join
	                                  ( SELECT a.VisitID, a.Provider, a.Ordinal, a.ProcedureCode,
	                                     (SELECT
	                                        VisitID as ''VisitID'',
	                                        Provider as ''Provider'',
	                                        Ordinal as ''Ordinal'',
	                                        ProcedureCode as ''ProcedureCode'',
	                                        DiagnosisCode as ''DiagnosisCode'',
	                                        DiagnosisDescription as ''DiagnosisDescription'',
	                                        [Version] as ''Version'',
	                                        DiagnosisOrdinal as ''DiagnosisOrdinal''
	                                     FROM VisitDiagnosis as b
	                                     where a.VisitID = b.VisitID
	                                     AND a.Provider = b.Provider
	                                     AND a.Ordinal = b.Ordinal
	                                     AND a.ProcedureCode = b.ProcedureCode
	                                     ORDER BY b.DiagnosisOrdinal
	                                     FOR XML PATH (''Dx''), TYPE
	                                     ) as rowXML
	                                   FROM VisitDiagnosis as a
	                                   GROUP BY VisitID, Provider, Ordinal, ProcedureCode
	                                  ) as Diagnoses
	                                  on Diagnoses.VisitID = procb.VisitID
	                                  and Diagnoses.ProcedureCode = procb.Code
	                                  and Diagnoses.Provider = procb.Provider
	                                  and Diagnoses.Ordinal = procb.Ordinal
	                                  where a.VisitID = procb.VisitID
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as procXML
	                                  FROM VisitProcedures as a
	                                  GROUP BY VisitID
	                                ) as ProcsAndDxs
	                                on vm.VisitID = ProcsAndDxs.VisitID
	                                left join
	                                (
	                                    select * FROM ( --this is for the grouping.
	                                        SELECT VisitID,
	                                        (
	                                            select * from ( --needs this to not complain about not being able to call FOR XML in subqueries and such..
	                                            SELECT 1 AS Tag,
	                                                0 AS Parent,
	                                                nm1.NoteMacroID					 AS [row!1!NoteMacroID!element],
	                                                COALESCE(nm1.MacroTypeID, -1)    AS [row!1!macroType!element],
	                                                nm1.MacroName					 AS [row!1!macroName!CDATA],
	                                                COALESCE(nm1.MacroContents, '''')	 AS [row!1!macroContents!CDATA],
	                                                COALESCE(nm1.MacroPointValue, 0) AS [row!1!MacroPointValue!element]
	                                            FROM VisitNoteMacros as b1
	                                              inner join NoteMacros as nm1
	                                              on b1.NoteMacroID = nm1.NoteMacroID
	                                            WHERE b1.VisitID = b.VisitID
	                                            ) f --needs this to not complain about not being able to call FOR XML in subqueries and such..
	                                            FOR XML EXPLICIT, root(''table'')
	                                        ) as [xml]
	                                        FROM VisitNoteMacros as b
	                                        join NoteMacros as nm
	                                        on b.NoteMacroID = nm.NoteMacroID
	                                    ) as NMs
	                                    GROUP BY NMs.VisitID, NMs.[xml]
	                                ) as VNoteMacros
	                                on vm.VisitID = VNoteMacros.VisitID
	                                left join v_OfficePoints as OfficePoints
	                                on vm.OfficeID = OfficePoints.OfficeID
	                                left join VisitHistoryLevels as vhl
	                                on vhl.VisitID = vm.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    COALESCE(historyElementValue, '''') as ''historyElementValue'',
	                                    HistoryItemID as ''HistoryItemID''
	                                  FROM VisitHistory as b
	                                  where a.VisitID = b.VisitID
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitHistory as a
	                                  GROUP BY VisitID
	                                ) as HistoryElements
	                                on vm.VisitID = HistoryElements.VisitID
	                                left join VisitHistoryUnobtainable as vhu
	                                on vhu.VisitID = vm.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    ExamTypeID as ''ExamTypeID'',
	                                    ExamElementID as ''ExamElementID''
	                                  FROM VisitExamElements as b
	                                  where a.VisitID = b.VisitID
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitExamElements as a
	                                  GROUP BY VisitID
	                                ) as ExamElements
	                                on vm.VisitID = ExamElements.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    COALESCE(NumberOfDiagnosis, -1) as ''NumberOfDiagnosis'',
	                                    COALESCE(EstablishedImproved, -1) as ''EstablishedImproved'',
	                                    COALESCE(EstablishedFailing, -1) as ''EstablishedFailing'',
	                                    COALESCE(NewNoAdditionalWork, -1) as ''NewNoAdditionalWork'',
	                                    COALESCE(NewAdditionalWork, -1) as ''NewAdditionalWork'',
	                                    ReviewLabTests as ''ReviewLabTests'',
	                                    ReviewRadiology as ''ReviewRadiology'',
	                                    ReviewMedicine as ''ReviewMedicine'',
	                                    DiscussTests as ''DiscussTests'',
	                                    IndependentReview as ''IndependentReview'',
	                                    DiscussOldRecords as ''DiscussOldRecords'',
	                                    ReviewOldRecords as ''ReviewOldRecords'',
	                                    COALESCE(Risk, '''') as ''Risk''
	                                  FROM VisitCMSDecision as b
	                                  where a.VisitID = b.VisitID
	                                  FOR XML PATH (''CMSDecision'')
	                                  ) as rowXML
	                                  FROM VisitCMSDecision as a
	                                  GROUP BY VisitID
	                                ) as CMSDecisionElements
	                                on vm.VisitID = CMSDecisionElements.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    COALESCE(ProblemsEvident, -1) as ''ProblemsEvident'',
	                                    OpenProcedure as ''OpenProcedure'',
	                                    PhysicalTherapy as ''PhysicalTherapy'',
	                                    ClosedTreatment as ''ClosedTreatment'',
	                                    IVFluids as ''IVFluids'',
	                                    ComplexInsulin as ''ComplexInsulin'',
	                                    ConservativeMeasures as ''ConservativeMeasures'',
	                                    RadiationTherapy as ''RadiationTherapy'',
	                                    JointInjection as ''JointInjection'',
	                                    PatientEducation as ''PatientEducation'',
	                                    AdmitHospital as ''AdmitHospital'',
	                                    DiscussCaseManagement_Options as ''DiscussCaseManagement_Options'',
	                                    Other as ''Other'',
	                                    COALESCE(LabProcedures, -1) as ''LabProcedures'',
	                                    COALESCE(RadiologyProcedures, -1) as ''RadiologyProcedures'',
	                                    COALESCE(MedicalProcedures, -1) as ''MedicalProcedures'',
	                                    COALESCE(IndependentVisualizations, -1) as ''IndependentVisualizations'',
	                                    DiscussTestResults as ''DiscussTestResults'',
	                                    DiscussCaseDataReviewed as ''DiscussCaseDataReviewed'',
	                                    PhysiologicMonitoring as ''PhysiologicMonitoring'',
	                                    OrderNoSummary as ''OrderNoSummary'',
	                                    OrderSummary as ''OrderSummary'',
	                                    COALESCE(DecisionProblems, '''') as ''DecisionProblems'',
	                                    COALESCE(DecisionRisk, '''') as ''DecisionRisk''
	                                  FROM VisitTrailblazerDecision as b
	                                  where a.VisitID = b.VisitID
	                                  FOR XML PATH (''TrailblazerDecision'')
	                                  ) as rowXML
	                                  FROM VisitTrailblazerDecision as a
	                                  GROUP BY VisitID
	                                ) as TrailblazerDecisionElements
	                                on vm.VisitID = TrailblazerDecisionElements.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitConsult as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitConsult as a
	                                  GROUP BY VisitID
	                                ) as ConsultQuestions
	                                on vm.VisitID = ConsultQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitIncidentTo as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitIncidentTo as a
	                                  GROUP BY VisitID
	                                ) as IncidentToQuestions
	                                on vm.VisitID = IncidentToQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    Selection as ''Selection''
	                                  FROM VisitMedicalNecessity as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitMedicalNecessity as a
	                                  GROUP BY VisitID
	                                ) as MedicalNecessityQuestions
	                                on vm.VisitID = MedicalNecessityQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    QuestionTypeID as ''QuestionTypeID'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitOtherQuestions as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitOtherQuestions as a
	                                  GROUP BY VisitID
	                                ) as OtherQuestions
	                                on vm.VisitID = OtherQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitPreventiveSplitVisit as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitPreventiveSplitVisit as a
	                                  GROUP BY VisitID
	                                ) as PreventiveSplitVisitQuestions
	                                on vm.VisitID = PreventiveSplitVisitQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitTeachingPhysician as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitTeachingPhysician as a
	                                  GROUP BY VisitID
	                                ) as TeachingPhysicianQuestions
	                                on vm.VisitID = TeachingPhysicianQuestions.VisitID
	                                left join
	                                ( SELECT VisitID,
	                                  (SELECT
	                                    VisitID as ''VisitID'',
	                                    QuestionNumber as ''QuestionNumber'',
	                                    COALESCE([Continue], '''') as ''Continue''
	                                  FROM VisitWelcomeToMedicare as b
	                                  where a.VisitID = b.VisitID
	                                  ORDER BY b.QuestionNumber
	                                  FOR XML PATH (''row''), ROOT(''table'')
	                                  ) as rowXML
	                                  FROM VisitWelcomeToMedicare as a
	                                  GROUP BY VisitID
	                                ) as WelcomeToMedicareQuestions
	                                on vm.VisitID = WelcomeToMedicareQuestions.VisitID
	                                left join
	                                (
	                                    SELECT DocumentID,
	                                        (SELECT
	                                            b.DocumentID as ''DocumentID'',
	                                            b.DocumentSecondaryID as ''DocumentSecondaryID'',
	                                            COALESCE(b.DocumentParentID, '''') as ''DocumentParentID'',
	                                            DocumentName as ''DocumentName'',
	                                            COALESCE(DocPages.rowXML, '''') as ''Pages''
	                                        FROM Documents as b
	                                        join
	                                            (SELECT DocumentID,
	                                                (SELECT p1.DocumentID as ''DocumentID'', p1.PageID as ''PageID'', p1.PageNumber as ''PageNumber'', p1.ImageID as ''ImageID'', img.PhysicalImage as ''Img'', COALESCE(pagePoints.rowXML, '''') as ''Points''
	                                                FROM Pages as p1
	                                                join Images as img
	                                                on img.ImageID = p1.ImageID
	                                                left join
	                                                (
	                                                    SELECT PageID,
	                                                    (
	                                                        SELECT DocumentID as ''DocumentID'', PageID as ''PageID'', PointID as ''PointID'', ElementTypeID as ''ElementTypeID'', ElementCategoryID as ''ElementCategoryID'', ElementID as ''ElementID'', StartX as ''StartX'', StartY as ''StartY'', EndX as ''EndX'', EndY as ''EndY'', Note as ''Note'', COALESCE(OtherGUID, '''') as ''OtherGUID'', Ordinal as ''Ordinal''
	                                                        FROM Points as points1
	                                                        WHERE points1.PageID = points2.PageID
	                                                        ORDER BY StartY, StartX, ElementTypeID, ElementCategoryID, ElementID, Ordinal
	                                                        FOR XML PATH (''Point''), TYPE
	                                                    )as rowXML
	                                                    FROM Points as points2
	                                                    GROUP BY PageID
	                                                ) as pagePoints
	                                                on pagePoints.PageID = p1.PageID
	                                                WHERE p1.DocumentID = p2.DocumentID AND p1.DocumentID = a.DocumentID
	                                                ORDER BY PageNumber
	                                                FOR XML PATH (''Page''), TYPE
	                                                ) as rowXML
	                                            FROM Pages as p2
	                                            GROUP BY DocumentID
	                                            ) as DocPages
	                                        on DocPages.DocumentID = b.DocumentID
	                                        where a.DocumentID = b.DocumentID
	                                        AND b.DocumentParentID is not null --must be an Audited Document to be used in a visit
	                                        FOR XML PATH (''Document''), TYPE
	                                        ) as rowXML
	                                    FROM Documents as a
	                                    WHERE a.DocumentParentID is not null
	                                    GROUP BY DocumentID
	                                ) as DocumentData
	                                on DocumentData.DocumentID = vm.AuditedDocumentID')
	UPDATE DatabaseVersion SET Version='72', SubVersion='0';
	set @Updated = @Updated + 1
	Print('Database Updated to 72.0')
END
IF @Updated = 0
BEGIN 
	DECLARE @Current varchar(10)
	SELECT @Current = Version + '.' + SubVersion FROM DatabaseVersion
	Print('Current version is ' + @Current + '. The database was not updated.')
END